==> activity-center-api-0.9.22-20190625.075140-23-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/CreditsConsumeDetailDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;
import io.swagger.models.auth.In;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: CreditsConsumeDetailDto <br/>
 * Function: 计划详情dto. <br/>
 * Reason: . <br/>
 * date: 2019年6月24日 上午10:46:51 <br/>
 *
 * @author scd
 * @version
 * @since JDK 1.8
 */
public class CreditsConsumeDetailDto extends BaseDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long              id;

    /** title:计划名称. */
    private String            title;

    /** status:0-关闭   1-打开. */
    private Integer           status;

    /** creator:创建人. */
    private String            creator;

    /** queryJobsUrl:任务条件查询接口链接. */
    private String            queryJobsUrl;

    /** queryJobsSwitch:查询任务接口开关 0-关闭 1-开启. */
    private Integer queryJobsSwitch;

    /** queryJobsType:任务频率类型. 0-每次参与活动时   1-用户每天第joinTime时   2 用户每天参与次数>= joinTime 时 */
    private Integer queryJobsType;

    /** queryJobsTime:参与次数. */
    private Integer queryJobsTime;

    /** reportJobsUrl:任务条件上报接口链接. */
    private String reportJobsUrl;

    /** reportJobsSwitch:上报任务接口开关. 0-关闭 1-开启 */
    private Integer reportJobsSwitch;

    /** reportJobsType:任务频率类型 0-每次参与活动时 1-用户每天第joinTime时 2 用户每天参与次数>= joinTime 时. */
    private Integer reportJobsType;

    /** reportJobsTime:参与次数. */
    private  Integer reportJobsTime;

    /** reportJobsParam:任务参数. */
    private String reportJobsParam;

    /** reportJobsRemark:任务备注. */
    private String reportJobsRemark;

    //积分消耗配置
    private List<CreditsConfigDto> creditsConfigDtoList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getQueryJobsUrl() {
        return queryJobsUrl;
    }

    public void setQueryJobsUrl(String queryJobsUrl) {
        this.queryJobsUrl = queryJobsUrl;
    }

    public Integer getQueryJobsSwitch() {
        return queryJobsSwitch;
    }

    public void setQueryJobsSwitch(Integer queryJobsSwitch) {
        this.queryJobsSwitch = queryJobsSwitch;
    }

    public Integer getQueryJobsType() {
        return queryJobsType;
    }

    public void setQueryJobsType(Integer queryJobsType) {
        this.queryJobsType = queryJobsType;
    }

    public Integer getQueryJobsTime() {
        return queryJobsTime;
    }

    public void setQueryJobsTime(Integer queryJobsTime) {
        this.queryJobsTime = queryJobsTime;
    }

    public String getReportJobsUrl() {
        return reportJobsUrl;
    }

    public void setReportJobsUrl(String reportJobsUrl) {
        this.reportJobsUrl = reportJobsUrl;
    }

    public Integer getReportJobsSwitch() {
        return reportJobsSwitch;
    }

    public void setReportJobsSwitch(Integer reportJobsSwitch) {
        this.reportJobsSwitch = reportJobsSwitch;
    }

    public Integer getReportJobsType() {
        return reportJobsType;
    }

    public void setReportJobsType(Integer reportJobsType) {
        this.reportJobsType = reportJobsType;
    }

    public Integer getReportJobsTime() {
        return reportJobsTime;
    }

    public void setReportJobsTime(Integer reportJobsTime) {
        this.reportJobsTime = reportJobsTime;
    }

    public String getReportJobsParam() {
        return reportJobsParam;
    }

    public void setReportJobsParam(String reportJobsParam) {
        this.reportJobsParam = reportJobsParam;
    }

    public String getReportJobsRemark() {
        return reportJobsRemark;
    }

    public void setReportJobsRemark(String reportJobsRemark) {
        this.reportJobsRemark = reportJobsRemark;
    }

    public List<CreditsConfigDto> getCreditsConfigDtoList() {
        return creditsConfigDtoList;
    }

    public void setCreditsConfigDtoList(List<CreditsConfigDto> creditsConfigDtoList) {
        this.creditsConfigDtoList = creditsConfigDtoList;
    }
}

==> activity-center-api-0.9.22-20190626.084529-45-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/CreditsConsumeDetailDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;
import io.swagger.models.auth.In;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: CreditsConsumeDetailDto <br/>
 * Function: 计划详情dto. <br/>
 * Reason: . <br/>
 * date: 2019年6月24日 上午10:46:51 <br/>
 *
 * @author scd
 * @version
 * @since JDK 1.8
 */
public class CreditsConsumeDetailDto extends BaseDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long              id;

    /** title:计划名称. */
    private String            title;

    /** status:0-关闭   1-打开. */
    private Integer           status;

    /** creator:创建人. */
    private String            creator;

    /** queryJobsUrl:任务条件查询接口链接. */
    private String            queryJobsUrl;

    /** queryJobsSwitch:查询任务接口开关 0-关闭 1-开启. */
    private Integer queryJobsSwitch;

    /** queryJobsType:任务频率类型. 0-每次参与活动时   1-用户每天第joinTime时   2 用户每天参与次数>= joinTime 时 */
    private Integer queryJobsType;

    /** queryJobsTime:参与次数. */
    private Integer queryJobsTime;

    /** reportJobsUrl:任务条件上报接口链接. */
    private String reportJobsUrl;

    /** reportJobsSwitch:上报任务接口开关. 0-关闭 1-开启 */
    private Integer reportJobsSwitch;

    /** reportJobsType:任务频率类型 0-每次参与活动时 1-用户每天第joinTime时 2 用户每天参与次数>= joinTime 时. */
    private Integer reportJobsType;

    /** reportJobsTime:参与次数. */
    private  Integer reportJobsTime;

    /** reportJobsParam:任务参数. */
    private String reportJobsParam;

    /** reportJobsRemark:任务备注. */
    private String reportJobsRemark;

    /** mediaSwitch:媒体定向开关. */
    private Integer mediaSwitch;

    /** slotSwitch:广告位定向开关. */
    private Integer slotSwitch;

    /** activitySwitch:活动定向开关. */
    private Integer activitySwitch;

    //积分消耗配置
    private List<CreditsConfigDto> creditsConfigDtoList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getQueryJobsUrl() {
        return queryJobsUrl;
    }

    public void setQueryJobsUrl(String queryJobsUrl) {
        this.queryJobsUrl = queryJobsUrl;
    }

    public Integer getQueryJobsSwitch() {
        return queryJobsSwitch;
    }

    public void setQueryJobsSwitch(Integer queryJobsSwitch) {
        this.queryJobsSwitch = queryJobsSwitch;
    }

    public Integer getQueryJobsType() {
        return queryJobsType;
    }

    public void setQueryJobsType(Integer queryJobsType) {
        this.queryJobsType = queryJobsType;
    }

    public Integer getQueryJobsTime() {
        return queryJobsTime;
    }

    public void setQueryJobsTime(Integer queryJobsTime) {
        this.queryJobsTime = queryJobsTime;
    }

    public String getReportJobsUrl() {
        return reportJobsUrl;
    }

    public void setReportJobsUrl(String reportJobsUrl) {
        this.reportJobsUrl = reportJobsUrl;
    }

    public Integer getReportJobsSwitch() {
        return reportJobsSwitch;
    }

    public void setReportJobsSwitch(Integer reportJobsSwitch) {
        this.reportJobsSwitch = reportJobsSwitch;
    }

    public Integer getReportJobsType() {
        return reportJobsType;
    }

    public void setReportJobsType(Integer reportJobsType) {
        this.reportJobsType = reportJobsType;
    }

    public Integer getReportJobsTime() {
        return reportJobsTime;
    }

    public void setReportJobsTime(Integer reportJobsTime) {
        this.reportJobsTime = reportJobsTime;
    }

    public String getReportJobsParam() {
        return reportJobsParam;
    }

    public void setReportJobsParam(String reportJobsParam) {
        this.reportJobsParam = reportJobsParam;
    }

    public String getReportJobsRemark() {
        return reportJobsRemark;
    }

    public void setReportJobsRemark(String reportJobsRemark) {
        this.reportJobsRemark = reportJobsRemark;
    }

    public List<CreditsConfigDto> getCreditsConfigDtoList() {
        return creditsConfigDtoList;
    }

    public void setCreditsConfigDtoList(List<CreditsConfigDto> creditsConfigDtoList) {
        this.creditsConfigDtoList = creditsConfigDtoList;
    }
}
